@@ -7,22 +7,22 @@ OBIGT()
 d2 <- thermo()$OBIGT
 expect_equal(d1, d2, info = info)
 
-info <- "checkGHS() and checkEOS() (via info()) produce messages"
+info <- "check.GHS() and check.EOS() (via info()) produce messages"
 i1 <- info("S2O3-2")
-expect_message(info(i1), "G of S2O3-2\\(aq\\) differs by 939 cal mol-1 from tabulated value", info = info)
+expect_message(info(i1), "calculated ΔG°f of S2O3-2\\(aq\\) differs by 939 cal mol-1 from database value", info = info)
 i2 <- info("Cu+2")
-expect_message(info(i2), "Cp of Cu\\+2\\(aq\\) differs by 3.62 cal K-1 mol-1 from tabulated value", info = info)
+expect_message(info(i2), "calculated Cp° of Cu\\+2\\(aq\\) differs by 3.62 cal K-1 mol-1 from database value", info = info)
 
-info <- "checkGHS() and checkEOS() respond to thermo()$opt$*.tol"
+info <- "check.GHS() and check.EOS() respond to thermo()$opt$*.tol"
 i1 <- info("SO4-2")
 thermo("opt$Cp.tol" = 0.5)
-expect_message(info(i1), "checkEOS", info = info)
+expect_message(info(i1), "check.EOS", info = info)
 i2 <- info("a,w-dicarboxytetracosane")
 thermo("opt$G.tol" = 50)
-expect_message(info(i2), "checkGHS", info = info)
+expect_message(info(i2), "check.GHS", info = info)
 
 info <- "RH2OBIGT() gives group additivity results consistent with database values (from Richard and Helgeson, 1998)"
-file <- system.file("extdata/adds/RH98_Table15.csv", package = "CHNOSZ")
+file <- system.file("extdata/misc/RH98_Table15.csv", package = "CHNOSZ")
 dat <- read.csv(file, stringsAsFactors = FALSE)
 ispecies <- info(dat$compound, dat$state)
 OBIGT.ref <- thermo()$OBIGT[ispecies, ]
@@ -44,7 +44,7 @@ info <- "add.OBIGT() replaces existing entries without changing species index"
 # Store the original species index of CdCl2
 iCdCl2 <- info("CdCl2", "aq")
 # Add supplemental database - includes CdCl2
-file <- system.file("extdata/adds/BZA10.csv", package = "CHNOSZ")
+file <- system.file("extdata/misc/BZA10.csv", package = "CHNOSZ")
 isp <- add.OBIGT(file)
 # Species index of CdCl2 should not have changed
 expect_equal(info("CdCl2", "aq"), iCdCl2, info = info)
@@ -61,10 +61,10 @@ expect_error(add.OBIGT(file), info = info)
 info <- "info() gives consistent messages for cal and J"
 # Test added 20190529
 # Add data for dimethylamine and trimethylamine in different units (cal or J)
-expect_message(add.OBIGT(system.file("extdata/adds/LA19_test.csv", package = "CHNOSZ")), "energy units: J and cal", info = info)
+expect_message(add.OBIGT(system.file("extdata/misc/LA19_test.csv", package = "CHNOSZ")), "energy units: J and cal", info = info)
 expect_message(info(info("DMA_cal")), "-1.92 cal", info = info)
 expect_message(info(info("DMA_J")), "-8.02 J", info = info)
-# For TMA, only a checkGHS message for the entry in J is produced,
+# For TMA, only a check.GHS message for the entry in J is produced,
 # because it's above the threshold of 100 set in thermo()$opt$G.tol
 expect_silent(info(info("TMA_cal")), info = info)
 expect_message(info(info("TMA_J")), "-102 J", info = info)
@@ -72,7 +72,7 @@ expect_message(info(info("TMA_J")), "-102 J", info = info)
 info <- "Missing values for G, Cp, and V are correct in cal and J"
 # Test added 20190530
 # Add data for dimethylamine and trimethylamine in different units (cal or J)
-add.OBIGT(system.file("extdata/adds/LA19_test.csv", package = "CHNOSZ"))
+add.OBIGT(system.file("extdata/misc/LA19_test.csv", package = "CHNOSZ"))
 calccal <- info(info("DMA_cal_NA"))
 expect_equal(round(calccal$G), 13934, info = info)
 expect_equal(round(calccal$Cp, 1), 60.3, info = info)
@@ -85,7 +85,7 @@ expect_equal(round(calcJ$V, 1), 58.2, info = info)
 info <- "subcrt() gives same results for data entered in cal and J"
 # Test added 20190530
 # Add data for dimethylamine and trimethylamine in different units (cal or J)
-add.OBIGT(system.file("extdata/adds/LA19_test.csv", package = "CHNOSZ"))
+add.OBIGT(system.file("extdata/misc/LA19_test.csv", package = "CHNOSZ"))
 E.units("cal")
 scal <- subcrt("DMA_cal")
 sJ <- subcrt("DMA_J")
@@ -120,15 +120,46 @@ info <- "We can define an aqueous species with CGL model"
 # Test added 20230220
 icr <- mod.OBIGT("fake_cr", formula = "Na2Cl2", state = "cr", model = "CGL", G = -1000, H = -1000, S = 10, Cp = 10, V = 10)
 iaq <- mod.OBIGT("fake_aq", formula = "Na2Cl2", state = "aq", model = "CGL", G = -1000, H = -1000, S = 10, Cp = 10, V = 10)
-# Make sure info() runs (message is from checkEOS())
+# Make sure info() runs (message is from check.EOS())
 expect_message(info(iaq), "differs", info = info)
 expect_silent(info(iaq), info = info)
 # Make sure subcrt() runs
 expect_equal(subcrt(iaq)$G, subcrt(icr)$G, info = info)
 
+# 20241225
+info <- "add.OBIGT() errors with non-existent file"
+file <- "XXX"
+expect_error(add.OBIGT(file), "XXX is not a file and doesn't match any files in the OBIGT database", info = info)
+
 # Reference
 
 # Richard, L. and Helgeson, H. C. (1998) Calculation of the thermodynamic properties at elevated 
 #   temperatures and pressures of saturated and aromatic high molecular weight solid and liquid 
 #   hydrocarbons in kerogen, bitumen, petroleum, and other organic matter of biogeochemical interest. 
 #   Geochim. Cosmochim. Acta 62, 3591--3636. https://doi.org/10.1016/S0016-7037(97)00345-1
+
+# Tests added on 20260107
+
+info <- "thermo.refs() creates HTML table without error"
+# Create the HTML but divert the output to a NULL connection
+expect_silent(thermo.refs(browser = sink), info = info)
+# Turn off the connection
+sink()
+
+info <- "thermo.refs() returns reference for source key"
+expect_equal(thermo.refs("HDNB78")$key, "HDNB78", info = info)
+
+info <- "thermo.refs() returns reference for species index"
+expect_equal(thermo.refs(info("SiO2"))$key, "SHS89", info = info)
+
+info <- "thermo.refs() returns references for subcrt() species output"
+expect_equal(thermo.refs(subcrt("carrollite"))$key, "HDR+24", info = info)
+
+info <- "thermo.refs() returns references for subcrt() reaction output"
+expect_equal(thermo.refs(subcrt(c("oxygen", "O2"), c(-1, 1)))$key, c("WEP+82", "SHS89", "Kel60"), info = info)
+
+info <- "check.OBIGT() runs without error"
+expect_silent(out <- check.OBIGT(), info = info)
+
+info <- "dumpdata() runs without error"
+expect_silent(dd <- dumpdata(), info = info)
